options pagesize=70 linesize=140;
ods _all_ close;
ods listing;
ods graphics off;

libname a "";

/* Run the program with method=ML and method=MLSB, separately. */
%let method=MLSB;


proc import datafile="vanDam2011.sav" out=vanDam2011 dbms=sav replace;
run;


data a.vanDam2011;
  set vanDam2011;
  keep ZI01_4nul ZI02_4nul ZI03_4nul ZI04_4nul ZI05_4nul ZI06_4nul ZI07_4nul ZI08_4nul ZI09_4nul ZI10_4nul
       CFCnul RF_prevnul RF_promnul VAL_altrnul VAL_biosnul VAL_egonul NEPnul
       ENV_idnul ENV_affnul ETHICnul HLTH_prvnul HLTH_cncnul SVO_dSocnul SVO_dIndnul SVO_dCmpmul;
run;


/* regular RA: 15 predictors, 10 outcomes */
proc iml;

use a.vanDam2011;
read all var {CFCnul RF_prevnul RF_promnul VAL_altrnul VAL_biosnul VAL_egonul NEPnul
              ENV_idnul ENV_affnul ETHICnul HLTH_prvnul HLTH_cncnul SVO_dSocnul SVO_dIndnul SVO_dCmpmul
              ZI01_4nul ZI02_4nul ZI03_4nul ZI04_4nul ZI05_4nul ZI06_4nul ZI07_4nul ZI08_4nul ZI09_4nul ZI10_4nul} into data [colname=varname];
close a.vanDam2011;

p = 15;
q = 10;

varname_X = varname[1,1:p];
varname_Y = varname[1,p+1:p+q];
print varname_X,, varname_Y;

samp_corr = corr(data);

/* X'X correlation matrix */
sigma_11 = samp_corr[1:p,1:p];

/* Y'X correlation matrix */
sigma_21 = samp_corr[p+1:p+q,1:p];
sigma_12 = T(sigma_21);

/* Y'Y correlation matrix */
sigma_22 = samp_corr[p+1:p+q,p+1:p+q];

/***********************************************************************/
/****************** create X-side redundancy variates ******************/
/***********************************************************************/
tri_prod = inv(sigma_11)*sigma_12*sigma_21;
call eigen(val,vec,tri_prod);
scale = sqrt(diag(T(vec)*sigma_11*vec));
weight = vec*inv(scale); /* X-side weight matrix */
/*print weight[f=12.9];*/

cov_comp = T(weight)*sigma_11*weight;
print cov_comp[f=7.3];

/* orthogonalize the last 5 columns */
call eigen(val,vec,cov_comp[q+1:p,q+1:p]);
trans = block(I(q),vec);
weight_trans = weight*trans;
scale_trans = sqrt(diag(T(weight_trans)*sigma_11*weight_trans));
weight_new = weight_trans*inv(scale_trans);

weight_new = weight_new*diag({1 -1 -1 1 1 1 1 1 -1 1 1 1 1 1 1});
cov_comp = T(weight_new)*sigma_11*weight_new;
print cov_comp[f=7.3];
print weight_new[f=12.9];

/* X-side loading matrix */
loading = inv(T(weight_new)); /* X-side loading matrix */
print loading[f=12.9];
/*print (sigma_11*weight_new)[f=12.9][l="Alternatively, loading = sigma_11*weight"];*/

crsloading = sigma_21*weight_new; /* cross-loading matrix between Y-side varaibles and X-side components */
print crsloading[f=12.9];

red = 1/q*vecdiag(T(crsloading[,1:q])*crsloading[,1:q]); /* Y-side redundancy given the X-side components */
red_cum = {
1 0 0 0 0 0 0 0 0 0,
1 1 0 0 0 0 0 0 0 0,
1 1 1 0 0 0 0 0 0 0,
1 1 1 1 0 0 0 0 0 0,
1 1 1 1 1 0 0 0 0 0,
1 1 1 1 1 1 0 0 0 0,
1 1 1 1 1 1 1 0 0 0,
1 1 1 1 1 1 1 1 0 0,
1 1 1 1 1 1 1 1 1 0,
1 1 1 1 1 1 1 1 1 1}*red;
print red[f=7.3] " " red_cum[f=7.3];

/* generate starting values for PROC CALIS */
vec_sd = std(data);
vec_lx = shape(loading[1:11,],1,0) || loading[12,1:14] || loading[13,1:13] || loading[14,1:12] || loading[15,1:11];
vec_corr_y = sigma_22[2,1] || sigma_22[3,1:2] || sigma_22[4,1:3] || sigma_22[5,1:4] || sigma_22[6,1:5]
             || sigma_22[7,1:6] || sigma_22[8,1:7] || sigma_22[9,1:8] || sigma_22[10,1:9];
vec_cly = shape(crsloading[1:q,1:q],1,0);
vec_unrot = vec_sd || vec_lx || vec_corr_y || vec_cly;
print (ncol(vec_unrot));

parmname = 
("sd1":"sd25") || {
  lx11    lx12    lx13    lx14    lx15    lx16    lx17    lx18    lx19   lx1_10   lx1_11   lx1_12   lx1_13   lx1_14   lx1_15
  lx21    lx22    lx23    lx24    lx25    lx26    lx27    lx28    lx29   lx2_10   lx2_11   lx2_12   lx2_13   lx2_14   lx2_15
  lx31    lx32    lx33    lx34    lx35    lx36    lx37    lx38    lx39   lx3_10   lx3_11   lx3_12   lx3_13   lx3_14   lx3_15
  lx41    lx42    lx43    lx44    lx45    lx46    lx47    lx48    lx49   lx4_10   lx4_11   lx4_12   lx4_13   lx4_14   lx4_15
  lx51    lx52    lx53    lx54    lx55    lx56    lx57    lx58    lx59   lx5_10   lx5_11   lx5_12   lx5_13   lx5_14   lx5_15
  lx61    lx62    lx63    lx64    lx65    lx66    lx67    lx68    lx69   lx6_10   lx6_11   lx6_12   lx6_13   lx6_14   lx6_15
  lx71    lx72    lx73    lx74    lx75    lx76    lx77    lx78    lx79   lx7_10   lx7_11   lx7_12   lx7_13   lx7_14   lx7_15
  lx81    lx82    lx83    lx84    lx85    lx86    lx87    lx88    lx89   lx8_10   lx8_11   lx8_12   lx8_13   lx8_14   lx8_15
  lx91    lx92    lx93    lx94    lx95    lx96    lx97    lx98    lx99   lx9_10   lx9_11   lx9_12   lx9_13   lx9_14   lx9_15
lx10_1  lx10_2  lx10_3  lx10_4  lx10_5  lx10_6  lx10_7  lx10_8  lx10_9  lx10_10  lx10_11  lx10_12  lx10_13  lx10_14  lx10_15
lx11_1  lx11_2  lx11_3  lx11_4  lx11_5  lx11_6  lx11_7  lx11_8  lx11_9  lx11_10  lx11_11  lx11_12  lx11_13  lx11_14  lx11_15
lx12_1  lx12_2  lx12_3  lx12_4  lx12_5  lx12_6  lx12_7  lx12_8  lx12_9  lx12_10  lx12_11  lx12_12  lx12_13  lx12_14
lx13_1  lx13_2  lx13_3  lx13_4  lx13_5  lx13_6  lx13_7  lx13_8  lx13_9  lx13_10  lx13_11  lx13_12  lx13_13
lx14_1  lx14_2  lx14_3  lx14_4  lx14_5  lx14_6  lx14_7  lx14_8  lx14_9  lx14_10  lx14_11  lx14_12
lx15_1  lx15_2  lx15_3  lx15_4  lx15_5  lx15_6  lx15_7  lx15_8  lx15_9  lx15_10  lx15_11
corr_y21
corr_y31  corr_y32
corr_y41  corr_y42  corr_y43
corr_y51  corr_y52  corr_y53  corr_y54
corr_y61  corr_y62  corr_y63  corr_y64  corr_y65
corr_y71  corr_y72  corr_y73  corr_y74  corr_y75  corr_y76
corr_y81  corr_y82  corr_y83  corr_y84  corr_y85  corr_y86  corr_y87
corr_y91  corr_y92  corr_y93  corr_y94  corr_y95  corr_y96  corr_y97  corr_y98
corr_y10_1  corr_y10_2  corr_y10_3  corr_y10_4  corr_y10_5  corr_y10_6  corr_y10_7  corr_y10_8  corr_y10_9
cly11  cly12  cly13  cly14  cly15  cly16  cly17  cly18  cly19  cly1_10
cly21  cly22  cly23  cly24  cly25  cly26  cly27  cly28  cly29  cly2_10
cly31  cly32  cly33  cly34  cly35  cly36  cly37  cly38  cly39  cly3_10
cly41  cly42  cly43  cly44  cly45  cly46  cly47  cly48  cly49  cly4_10
cly51  cly52  cly53  cly54  cly55  cly56  cly57  cly58  cly59  cly5_10
cly61  cly62  cly63  cly64  cly65  cly66  cly67  cly68  cly69  cly6_10
cly71  cly72  cly73  cly74  cly75  cly76  cly77  cly78  cly79  cly7_10
cly81  cly82  cly83  cly84  cly85  cly86  cly87  cly88  cly89  cly8_10
cly91  cly92  cly93  cly94  cly95  cly96  cly97  cly98  cly99  cly9_10
cly10_1  cly10_2  cly10_3  cly10_4  cly10_5  cly10_6  cly10_7  cly10_8  cly10_9  cly10_10};
print (ncol(parmname));
_TYPE_ = {"PARMS"};
create vec_unrot from vec_unrot [colname=parmname rowname=_TYPE_];
append from vec_unrot [rowname=_TYPE_];
close vec_unrot;

quit;


/* RA-L */
proc calis data=a.vanDam2011 method=&method. dfreduce=-60 ci inest=vec_unrot outest=est;
  nloptions absconv=1e-32 absfconv=0 absgconv=0 absxconv=0 fconv=0 fconv2=0 gconv=0 gconv2=0;
  cosan
    var = CFCnul RF_prevnul RF_promnul VAL_altrnul VAL_biosnul VAL_egonul NEPnul
          ENV_idnul ENV_affnul ETHICnul HLTH_prvnul HLTH_cncnul SVO_dSocnul SVO_dIndnul SVO_dCmpmul
          ZI01_4nul ZI02_4nul ZI03_4nul ZI04_4nul ZI05_4nul ZI06_4nul ZI07_4nul ZI08_4nul ZI09_4nul ZI10_4nul,
    F2(25,DIA) * F1(25,GEN) * P(25,SYM);
  matrix F2
    [1,1] = sd1-sd25;
  matrix F1
    [@1,1] =    lx11    lx12    lx13    lx14    lx15    lx16    lx17    lx18    lx19   lx1_10   lx1_11   lx1_12   lx1_13   lx1_14   lx1_15,
    [@2,1] =    lx21    lx22    lx23    lx24    lx25    lx26    lx27    lx28    lx29   lx2_10   lx2_11   lx2_12   lx2_13   lx2_14   lx2_15,
    [@3,1] =    lx31    lx32    lx33    lx34    lx35    lx36    lx37    lx38    lx39   lx3_10   lx3_11   lx3_12   lx3_13   lx3_14   lx3_15,
    [@4,1] =    lx41    lx42    lx43    lx44    lx45    lx46    lx47    lx48    lx49   lx4_10   lx4_11   lx4_12   lx4_13   lx4_14   lx4_15,
    [@5,1] =    lx51    lx52    lx53    lx54    lx55    lx56    lx57    lx58    lx59   lx5_10   lx5_11   lx5_12   lx5_13   lx5_14   lx5_15,
    [@6,1] =    lx61    lx62    lx63    lx64    lx65    lx66    lx67    lx68    lx69   lx6_10   lx6_11   lx6_12   lx6_13   lx6_14   lx6_15,
    [@7,1] =    lx71    lx72    lx73    lx74    lx75    lx76    lx77    lx78    lx79   lx7_10   lx7_11   lx7_12   lx7_13   lx7_14   lx7_15,
    [@8,1] =    lx81    lx82    lx83    lx84    lx85    lx86    lx87    lx88    lx89   lx8_10   lx8_11   lx8_12   lx8_13   lx8_14   lx8_15,
    [@9,1] =    lx91    lx92    lx93    lx94    lx95    lx96    lx97    lx98    lx99   lx9_10   lx9_11   lx9_12   lx9_13   lx9_14   lx9_15,
    [@10,1] = lx10_1  lx10_2  lx10_3  lx10_4  lx10_5  lx10_6  lx10_7  lx10_8  lx10_9  lx10_10  lx10_11  lx10_12  lx10_13  lx10_14  lx10_15,
    [@11,1] = lx11_1  lx11_2  lx11_3  lx11_4  lx11_5  lx11_6  lx11_7  lx11_8  lx11_9  lx11_10  lx11_11  lx11_12  lx11_13  lx11_14  lx11_15,
    [@12,1] = lx12_1  lx12_2  lx12_3  lx12_4  lx12_5  lx12_6  lx12_7  lx12_8  lx12_9  lx12_10  lx12_11  lx12_12  lx12_13  lx12_14  0.122275143,
    [@13,1] = lx13_1  lx13_2  lx13_3  lx13_4  lx13_5  lx13_6  lx13_7  lx13_8  lx13_9  lx13_10  lx13_11  lx13_12  lx13_13  -0.173360631 -0.057612697,
    [@14,1] = lx14_1  lx14_2  lx14_3  lx14_4  lx14_5  lx14_6  lx14_7  lx14_8  lx14_9  lx14_10  lx14_11  lx14_12  -0.098943935  0.033576129  0.393775731,
    [@15,1] = lx15_1  lx15_2  lx15_3  lx15_4  lx15_5  lx15_6  lx15_7  lx15_8  lx15_9  lx15_10  lx15_11  0.055541165 -0.314694613  0.624462503 -0.291369847,
    [16,16] = 10*1;
  matrix P
    [1,1]  = 25*1,
    [@17,16] = corr_y21,
    [@18,16] = corr_y31  corr_y32,
    [@19,16] = corr_y41  corr_y42  corr_y43,
    [@20,16] = corr_y51  corr_y52  corr_y53  corr_y54,
    [@21,16] = corr_y61  corr_y62  corr_y63  corr_y64  corr_y65,
    [@22,16] = corr_y71  corr_y72  corr_y73  corr_y74  corr_y75  corr_y76,
    [@23,16] = corr_y81  corr_y82  corr_y83  corr_y84  corr_y85  corr_y86  corr_y87,
    [@24,16] = corr_y91  corr_y92  corr_y93  corr_y94  corr_y95  corr_y96  corr_y97  corr_y98,
    [@25,16] = corr_y10_1  corr_y10_2  corr_y10_3  corr_y10_4  corr_y10_5  corr_y10_6  corr_y10_7  corr_y10_8  corr_y10_9,
    [@16,1] = cly11  cly12  cly13  cly14  cly15  cly16  cly17  cly18  cly19  cly1_10,
    [@17,1] = cly21  cly22  cly23  cly24  cly25  cly26  cly27  cly28  cly29  cly2_10,
    [@18,1] = cly31  cly32  cly33  cly34  cly35  cly36  cly37  cly38  cly39  cly3_10,
    [@19,1] = cly41  cly42  cly43  cly44  cly45  cly46  cly47  cly48  cly49  cly4_10,
    [@20,1] = cly51  cly52  cly53  cly54  cly55  cly56  cly57  cly58  cly59  cly5_10,
    [@21,1] = cly61  cly62  cly63  cly64  cly65  cly66  cly67  cly68  cly69  cly6_10,
    [@22,1] = cly71  cly72  cly73  cly74  cly75  cly76  cly77  cly78  cly79  cly7_10,
    [@23,1] = cly81  cly82  cly83  cly84  cly85  cly86  cly87  cly88  cly89  cly8_10,
    [@24,1] = cly91  cly92  cly93  cly94  cly95  cly96  cly97  cly98  cly99  cly9_10,
    [@25,1] = cly10_1  cly10_2  cly10_3  cly10_4  cly10_5  cly10_6  cly10_7  cly10_8  cly10_9  cly10_10;
  nlincon
    diag1-diag15=1,
    constr21=0,
    constr31=0, constr32=0,
    constr41=0, constr42=0, constr43=0,
    constr51=0, constr52=0, constr53=0, constr54=0,
    constr61=0, constr62=0, constr63=0, constr64=0, constr65=0,
    constr71=0, constr72=0, constr73=0, constr74=0, constr75=0, constr76=0,
    constr81=0, constr82=0, constr83=0, constr84=0, constr85=0, constr86=0, constr87=0,
    constr91=0, constr92=0, constr93=0, constr94=0, constr95=0, constr96=0, constr97=0, constr98=0,
    constr10_1=0, constr10_2=0, constr10_3=0, constr10_4=0, constr10_5=0, constr10_6=0, constr10_7=0, constr10_8=0, constr10_9=0;
 parameters
    diag1-diag15
    constr21
    constr31 constr32
    constr41 constr42 constr43
    constr51 constr52 constr53 constr54
    constr61 constr62 constr63 constr64 constr65
    constr71 constr72 constr73 constr74 constr75 constr76
    constr81 constr82 constr83 constr84 constr85 constr86 constr87
    constr91 constr92 constr93 constr94 constr95 constr96 constr97 constr98
    constr10_1 constr10_2 constr10_3 constr10_4 constr10_5 constr10_6 constr10_7 constr10_8 constr10_9
    red1-red10 cum_red2-cum_red10;
/* specify the programming statements below */
    diag1 = lx11**2 + lx12**2 + lx13**2 + lx14**2 + lx15**2 + lx16**2 + lx17**2 + lx18**2 + lx19**2 + lx1_10**2 + lx1_11**2 + lx1_12**2 + lx1_13**2 + lx1_14**2 + lx1_15**2;
    diag2 = lx21**2 + lx22**2 + lx23**2 + lx24**2 + lx25**2 + lx26**2 + lx27**2 + lx28**2 + lx29**2 + lx2_10**2 + lx2_11**2 + lx2_12**2 + lx2_13**2 + lx2_14**2 + lx2_15**2;
    diag3 = lx31**2 + lx32**2 + lx33**2 + lx34**2 + lx35**2 + lx36**2 + lx37**2 + lx38**2 + lx39**2 + lx3_10**2 + lx3_11**2 + lx3_12**2 + lx3_13**2 + lx3_14**2 + lx3_15**2;
    diag4 = lx41**2 + lx42**2 + lx43**2 + lx44**2 + lx45**2 + lx46**2 + lx47**2 + lx48**2 + lx49**2 + lx4_10**2 + lx4_11**2 + lx4_12**2 + lx4_13**2 + lx4_14**2 + lx4_15**2;
    diag5 = lx51**2 + lx52**2 + lx53**2 + lx54**2 + lx55**2 + lx56**2 + lx57**2 + lx58**2 + lx59**2 + lx5_10**2 + lx5_11**2 + lx5_12**2 + lx5_13**2 + lx5_14**2 + lx5_15**2;
    diag6 = lx61**2 + lx62**2 + lx63**2 + lx64**2 + lx65**2 + lx66**2 + lx67**2 + lx68**2 + lx69**2 + lx6_10**2 + lx6_11**2 + lx6_12**2 + lx6_13**2 + lx6_14**2 + lx6_15**2;
    diag7 = lx71**2 + lx72**2 + lx73**2 + lx74**2 + lx75**2 + lx76**2 + lx77**2 + lx78**2 + lx79**2 + lx7_10**2 + lx7_11**2 + lx7_12**2 + lx7_13**2 + lx7_14**2 + lx7_15**2;
    diag8 = lx81**2 + lx82**2 + lx83**2 + lx84**2 + lx85**2 + lx86**2 + lx87**2 + lx88**2 + lx89**2 + lx8_10**2 + lx8_11**2 + lx8_12**2 + lx8_13**2 + lx8_14**2 + lx8_15**2;
    diag9 = lx91**2 + lx92**2 + lx93**2 + lx94**2 + lx95**2 + lx96**2 + lx97**2 + lx98**2 + lx99**2 + lx9_10**2 + lx9_11**2 + lx9_12**2 + lx9_13**2 + lx9_14**2 + lx9_15**2;
    diag10 = lx10_1**2 + lx10_2**2 + lx10_3**2 + lx10_4**2 + lx10_5**2 + lx10_6**2 + lx10_7**2 + lx10_8**2 + lx10_9**2 + lx10_10**2 + lx10_11**2 + lx10_12**2 + lx10_13**2 + lx10_14**2 + lx10_15**2;
    diag11 = lx11_1**2 + lx11_2**2 + lx11_3**2 + lx11_4**2 + lx11_5**2 + lx11_6**2 + lx11_7**2 + lx11_8**2 + lx11_9**2 + lx11_10**2 + lx11_11**2 + lx11_12**2 + lx11_13**2 + lx11_14**2 + lx11_15**2;
    diag12 = lx12_1**2 + lx12_2**2 + lx12_3**2 + lx12_4**2 + lx12_5**2 + lx12_6**2 + lx12_7**2 + lx12_8**2 + lx12_9**2 + lx12_10**2 + lx12_11**2 + lx12_12**2 + lx12_13**2 + lx12_14**2 + 0.122275143**2;
    diag13 = lx13_1**2 + lx13_2**2 + lx13_3**2 + lx13_4**2 + lx13_5**2 + lx13_6**2 + lx13_7**2 + lx13_8**2 + lx13_9**2 + lx13_10**2 + lx13_11**2 + lx13_12**2 + lx13_13**2 + (-0.173360631)**2 + (-0.057612697)**2;
    diag14 = lx14_1**2 + lx14_2**2 + lx14_3**2 + lx14_4**2 + lx14_5**2 + lx14_6**2 + lx14_7**2 + lx14_8**2 + lx14_9**2 + lx14_10**2 + lx14_11**2 + lx14_12**2 + (-0.098943935)**2 + 0.033576129**2 + 0.393775731**2;
    diag15 = lx15_1**2 + lx15_2**2 + lx15_3**2 + lx15_4**2 + lx15_5**2 + lx15_6**2 + lx15_7**2 + lx15_8**2 + lx15_9**2 + lx15_10**2 + lx15_11**2 + 0.055541165**2 + (-0.314694613)**2 + 0.624462503**2 + (-0.291369847)**2;
    constr21 = cly12*cly11 + cly22*cly21 + cly32*cly31 + cly42*cly41 + cly52*cly51 + cly62*cly61 + cly72*cly71 + cly82*cly81 + cly92*cly91 + cly10_2*cly10_1;
    constr31 = cly13*cly11 + cly23*cly21 + cly33*cly31 + cly43*cly41 + cly53*cly51 + cly63*cly61 + cly73*cly71 + cly83*cly81 + cly93*cly91 + cly10_3*cly10_1;
    constr32 = cly13*cly12 + cly23*cly22 + cly33*cly32 + cly43*cly42 + cly53*cly52 + cly63*cly62 + cly73*cly72 + cly83*cly82 + cly93*cly92 + cly10_3*cly10_2;
    constr41 = cly14*cly11 + cly24*cly21 + cly34*cly31 + cly44*cly41 + cly54*cly51 + cly64*cly61 + cly74*cly71 + cly84*cly81 + cly94*cly91 + cly10_4*cly10_1;
    constr42 = cly14*cly12 + cly24*cly22 + cly34*cly32 + cly44*cly42 + cly54*cly52 + cly64*cly62 + cly74*cly72 + cly84*cly82 + cly94*cly92 + cly10_4*cly10_2;
    constr43 = cly14*cly13 + cly24*cly23 + cly34*cly33 + cly44*cly43 + cly54*cly53 + cly64*cly63 + cly74*cly73 + cly84*cly83 + cly94*cly93 + cly10_4*cly10_3;
    constr51 = cly15*cly11 + cly25*cly21 + cly35*cly31 + cly45*cly41 + cly55*cly51 + cly65*cly61 + cly75*cly71 + cly85*cly81 + cly95*cly91 + cly10_5*cly10_1;
    constr52 = cly15*cly12 + cly25*cly22 + cly35*cly32 + cly45*cly42 + cly55*cly52 + cly65*cly62 + cly75*cly72 + cly85*cly82 + cly95*cly92 + cly10_5*cly10_2;
    constr53 = cly15*cly13 + cly25*cly23 + cly35*cly33 + cly45*cly43 + cly55*cly53 + cly65*cly63 + cly75*cly73 + cly85*cly83 + cly95*cly93 + cly10_5*cly10_3;
    constr54 = cly15*cly14 + cly25*cly24 + cly35*cly34 + cly45*cly44 + cly55*cly54 + cly65*cly64 + cly75*cly74 + cly85*cly84 + cly95*cly94 + cly10_5*cly10_4;
    constr61 = cly16*cly11 + cly26*cly21 + cly36*cly31 + cly46*cly41 + cly56*cly51 + cly66*cly61 + cly76*cly71 + cly86*cly81 + cly96*cly91 + cly10_6*cly10_1;
    constr62 = cly16*cly12 + cly26*cly22 + cly36*cly32 + cly46*cly42 + cly56*cly52 + cly66*cly62 + cly76*cly72 + cly86*cly82 + cly96*cly92 + cly10_6*cly10_2;
    constr63 = cly16*cly13 + cly26*cly23 + cly36*cly33 + cly46*cly43 + cly56*cly53 + cly66*cly63 + cly76*cly73 + cly86*cly83 + cly96*cly93 + cly10_6*cly10_3;
    constr64 = cly16*cly14 + cly26*cly24 + cly36*cly34 + cly46*cly44 + cly56*cly54 + cly66*cly64 + cly76*cly74 + cly86*cly84 + cly96*cly94 + cly10_6*cly10_4;
    constr65 = cly16*cly15 + cly26*cly25 + cly36*cly35 + cly46*cly45 + cly56*cly55 + cly66*cly65 + cly76*cly75 + cly86*cly85 + cly96*cly95 + cly10_6*cly10_5;
    constr71 = cly17*cly11 + cly27*cly21 + cly37*cly31 + cly47*cly41 + cly57*cly51 + cly67*cly61 + cly77*cly71 + cly87*cly81 + cly97*cly91 + cly10_7*cly10_1;
    constr72 = cly17*cly12 + cly27*cly22 + cly37*cly32 + cly47*cly42 + cly57*cly52 + cly67*cly62 + cly77*cly72 + cly87*cly82 + cly97*cly92 + cly10_7*cly10_2;
    constr73 = cly17*cly13 + cly27*cly23 + cly37*cly33 + cly47*cly43 + cly57*cly53 + cly67*cly63 + cly77*cly73 + cly87*cly83 + cly97*cly93 + cly10_7*cly10_3;
    constr74 = cly17*cly14 + cly27*cly24 + cly37*cly34 + cly47*cly44 + cly57*cly54 + cly67*cly64 + cly77*cly74 + cly87*cly84 + cly97*cly94 + cly10_7*cly10_4;
    constr75 = cly17*cly15 + cly27*cly25 + cly37*cly35 + cly47*cly45 + cly57*cly55 + cly67*cly65 + cly77*cly75 + cly87*cly85 + cly97*cly95 + cly10_7*cly10_5;
    constr76 = cly17*cly16 + cly27*cly26 + cly37*cly36 + cly47*cly46 + cly57*cly56 + cly67*cly66 + cly77*cly76 + cly87*cly86 + cly97*cly96 + cly10_7*cly10_6;
    constr81 = cly18*cly11 + cly28*cly21 + cly38*cly31 + cly48*cly41 + cly58*cly51 + cly68*cly61 + cly78*cly71 + cly88*cly81 + cly98*cly91 + cly10_8*cly10_1;
    constr82 = cly18*cly12 + cly28*cly22 + cly38*cly32 + cly48*cly42 + cly58*cly52 + cly68*cly62 + cly78*cly72 + cly88*cly82 + cly98*cly92 + cly10_8*cly10_2;
    constr83 = cly18*cly13 + cly28*cly23 + cly38*cly33 + cly48*cly43 + cly58*cly53 + cly68*cly63 + cly78*cly73 + cly88*cly83 + cly98*cly93 + cly10_8*cly10_3;
    constr84 = cly18*cly14 + cly28*cly24 + cly38*cly34 + cly48*cly44 + cly58*cly54 + cly68*cly64 + cly78*cly74 + cly88*cly84 + cly98*cly94 + cly10_8*cly10_4;
    constr85 = cly18*cly15 + cly28*cly25 + cly38*cly35 + cly48*cly45 + cly58*cly55 + cly68*cly65 + cly78*cly75 + cly88*cly85 + cly98*cly95 + cly10_8*cly10_5;
    constr86 = cly18*cly16 + cly28*cly26 + cly38*cly36 + cly48*cly46 + cly58*cly56 + cly68*cly66 + cly78*cly76 + cly88*cly86 + cly98*cly96 + cly10_8*cly10_6;
    constr87 = cly18*cly17 + cly28*cly27 + cly38*cly37 + cly48*cly47 + cly58*cly57 + cly68*cly67 + cly78*cly77 + cly88*cly87 + cly98*cly97 + cly10_8*cly10_7;
    constr91 = cly19*cly11 + cly29*cly21 + cly39*cly31 + cly49*cly41 + cly59*cly51 + cly69*cly61 + cly79*cly71 + cly89*cly81 + cly99*cly91 + cly10_9*cly10_1;
    constr92 = cly19*cly12 + cly29*cly22 + cly39*cly32 + cly49*cly42 + cly59*cly52 + cly69*cly62 + cly79*cly72 + cly89*cly82 + cly99*cly92 + cly10_9*cly10_2;
    constr93 = cly19*cly13 + cly29*cly23 + cly39*cly33 + cly49*cly43 + cly59*cly53 + cly69*cly63 + cly79*cly73 + cly89*cly83 + cly99*cly93 + cly10_9*cly10_3;
    constr94 = cly19*cly14 + cly29*cly24 + cly39*cly34 + cly49*cly44 + cly59*cly54 + cly69*cly64 + cly79*cly74 + cly89*cly84 + cly99*cly94 + cly10_9*cly10_4;
    constr95 = cly19*cly15 + cly29*cly25 + cly39*cly35 + cly49*cly45 + cly59*cly55 + cly69*cly65 + cly79*cly75 + cly89*cly85 + cly99*cly95 + cly10_9*cly10_5;
    constr96 = cly19*cly16 + cly29*cly26 + cly39*cly36 + cly49*cly46 + cly59*cly56 + cly69*cly66 + cly79*cly76 + cly89*cly86 + cly99*cly96 + cly10_9*cly10_6;
    constr97 = cly19*cly17 + cly29*cly27 + cly39*cly37 + cly49*cly47 + cly59*cly57 + cly69*cly67 + cly79*cly77 + cly89*cly87 + cly99*cly97 + cly10_9*cly10_7;
    constr98 = cly19*cly18 + cly29*cly28 + cly39*cly38 + cly49*cly48 + cly59*cly58 + cly69*cly68 + cly79*cly78 + cly89*cly88 + cly99*cly98 + cly10_9*cly10_8;
    constr10_1 = cly1_10*cly11 + cly2_10*cly21 + cly3_10*cly31 + cly4_10*cly41 + cly5_10*cly51 + cly6_10*cly61 + cly7_10*cly71 + cly8_10*cly81 + cly9_10*cly91 + cly10_10*cly10_1;
    constr10_2 = cly1_10*cly12 + cly2_10*cly22 + cly3_10*cly32 + cly4_10*cly42 + cly5_10*cly52 + cly6_10*cly62 + cly7_10*cly72 + cly8_10*cly82 + cly9_10*cly92 + cly10_10*cly10_2;
    constr10_3 = cly1_10*cly13 + cly2_10*cly23 + cly3_10*cly33 + cly4_10*cly43 + cly5_10*cly53 + cly6_10*cly63 + cly7_10*cly73 + cly8_10*cly83 + cly9_10*cly93 + cly10_10*cly10_3;
    constr10_4 = cly1_10*cly14 + cly2_10*cly24 + cly3_10*cly34 + cly4_10*cly44 + cly5_10*cly54 + cly6_10*cly64 + cly7_10*cly74 + cly8_10*cly84 + cly9_10*cly94 + cly10_10*cly10_4;
    constr10_5 = cly1_10*cly15 + cly2_10*cly25 + cly3_10*cly35 + cly4_10*cly45 + cly5_10*cly55 + cly6_10*cly65 + cly7_10*cly75 + cly8_10*cly85 + cly9_10*cly95 + cly10_10*cly10_5;
    constr10_6 = cly1_10*cly16 + cly2_10*cly26 + cly3_10*cly36 + cly4_10*cly46 + cly5_10*cly56 + cly6_10*cly66 + cly7_10*cly76 + cly8_10*cly86 + cly9_10*cly96 + cly10_10*cly10_6;
    constr10_7 = cly1_10*cly17 + cly2_10*cly27 + cly3_10*cly37 + cly4_10*cly47 + cly5_10*cly57 + cly6_10*cly67 + cly7_10*cly77 + cly8_10*cly87 + cly9_10*cly97 + cly10_10*cly10_7;
    constr10_8 = cly1_10*cly18 + cly2_10*cly28 + cly3_10*cly38 + cly4_10*cly48 + cly5_10*cly58 + cly6_10*cly68 + cly7_10*cly78 + cly8_10*cly88 + cly9_10*cly98 + cly10_10*cly10_8;
    constr10_9 = cly1_10*cly19 + cly2_10*cly29 + cly3_10*cly39 + cly4_10*cly49 + cly5_10*cly59 + cly6_10*cly69 + cly7_10*cly79 + cly8_10*cly89 + cly9_10*cly99 + cly10_10*cly10_9;
    red1 = 1/10*(cly11**2 + cly21**2 + cly31**2 + cly41**2 + cly51**2 + cly61**2 + cly71**2 + cly81**2 + cly91**2 + cly10_1**2);
    red2 = 1/10*(cly12**2 + cly22**2 + cly32**2 + cly42**2 + cly52**2 + cly62**2 + cly72**2 + cly82**2 + cly92**2 + cly10_2**2);
    red3 = 1/10*(cly13**2 + cly23**2 + cly33**2 + cly43**2 + cly53**2 + cly63**2 + cly73**2 + cly83**2 + cly93**2 + cly10_3**2);
    red4 = 1/10*(cly14**2 + cly24**2 + cly34**2 + cly44**2 + cly54**2 + cly64**2 + cly74**2 + cly84**2 + cly94**2 + cly10_4**2);
    red5 = 1/10*(cly15**2 + cly25**2 + cly35**2 + cly45**2 + cly55**2 + cly65**2 + cly75**2 + cly85**2 + cly95**2 + cly10_5**2);
    red6 = 1/10*(cly16**2 + cly26**2 + cly36**2 + cly46**2 + cly56**2 + cly66**2 + cly76**2 + cly86**2 + cly96**2 + cly10_6**2);
    red7 = 1/10*(cly17**2 + cly27**2 + cly37**2 + cly47**2 + cly57**2 + cly67**2 + cly77**2 + cly87**2 + cly97**2 + cly10_7**2);
    red8 = 1/10*(cly18**2 + cly28**2 + cly38**2 + cly48**2 + cly58**2 + cly68**2 + cly78**2 + cly88**2 + cly98**2 + cly10_8**2);
    red9 = 1/10*(cly19**2 + cly29**2 + cly39**2 + cly49**2 + cly59**2 + cly69**2 + cly79**2 + cly89**2 + cly99**2 + cly10_9**2);
    red10 =1/10*(cly1_10**2 + cly2_10**2 + cly3_10**2 + cly4_10**2 + cly5_10**2 + cly6_10**2 + cly7_10**2 + cly8_10**2 + cly9_10**2 + cly10_10**2);
    cum_red2 = red1 + red2;
    cum_red3 = red1 + red2 + red3;
    cum_red4 = red1 + red2 + red3 + red4;
    cum_red5 = red1 + red2 + red3 + red4 + red5;
    cum_red6 = red1 + red2 + red3 + red4 + red5 + red6;
    cum_red7 = red1 + red2 + red3 + red4 + red5 + red6 + red7;
    cum_red8 = red1 + red2 + red3 + red4 + red5 + red6 + red7 + red8;
    cum_red9 = red1 + red2 + red3 + red4 + red5 + red6 + red7 + red8 + red9;
    cum_red10 = red1 + red2 + red3 + red4 + red5 + red6 + red7 + red8 + red9 + red10;
run;


/* print CALIS results */
proc iml;

use est;
read all var ("sd1":"sd15") where (_TYPE_="PARMS") into Dx_hat[colname=Dx_name];
read all var ("sd16":"sd25") where (_TYPE_="PARMS") into Dy_hat[colname=Dy_name];
read all var {
  lx11    lx12    lx13    lx14    lx15    lx16    lx17    lx18    lx19   lx1_10   lx1_11   lx1_12   lx1_13   lx1_14   lx1_15
  lx21    lx22    lx23    lx24    lx25    lx26    lx27    lx28    lx29   lx2_10   lx2_11   lx2_12   lx2_13   lx2_14   lx2_15
  lx31    lx32    lx33    lx34    lx35    lx36    lx37    lx38    lx39   lx3_10   lx3_11   lx3_12   lx3_13   lx3_14   lx3_15
  lx41    lx42    lx43    lx44    lx45    lx46    lx47    lx48    lx49   lx4_10   lx4_11   lx4_12   lx4_13   lx4_14   lx4_15
  lx51    lx52    lx53    lx54    lx55    lx56    lx57    lx58    lx59   lx5_10   lx5_11   lx5_12   lx5_13   lx5_14   lx5_15
  lx61    lx62    lx63    lx64    lx65    lx66    lx67    lx68    lx69   lx6_10   lx6_11   lx6_12   lx6_13   lx6_14   lx6_15
  lx71    lx72    lx73    lx74    lx75    lx76    lx77    lx78    lx79   lx7_10   lx7_11   lx7_12   lx7_13   lx7_14   lx7_15
  lx81    lx82    lx83    lx84    lx85    lx86    lx87    lx88    lx89   lx8_10   lx8_11   lx8_12   lx8_13   lx8_14   lx8_15
  lx91    lx92    lx93    lx94    lx95    lx96    lx97    lx98    lx99   lx9_10   lx9_11   lx9_12   lx9_13   lx9_14   lx9_15
lx10_1  lx10_2  lx10_3  lx10_4  lx10_5  lx10_6  lx10_7  lx10_8  lx10_9  lx10_10  lx10_11  lx10_12  lx10_13  lx10_14  lx10_15
lx11_1  lx11_2  lx11_3  lx11_4  lx11_5  lx11_6  lx11_7  lx11_8  lx11_9  lx11_10  lx11_11  lx11_12  lx11_13  lx11_14  lx11_15
lx12_1  lx12_2  lx12_3  lx12_4  lx12_5  lx12_6  lx12_7  lx12_8  lx12_9  lx12_10  lx12_11  lx12_12  lx12_13  lx12_14
lx13_1  lx13_2  lx13_3  lx13_4  lx13_5  lx13_6  lx13_7  lx13_8  lx13_9  lx13_10  lx13_11  lx13_12  lx13_13
lx14_1  lx14_2  lx14_3  lx14_4  lx14_5  lx14_6  lx14_7  lx14_8  lx14_9  lx14_10  lx14_11  lx14_12
lx15_1  lx15_2  lx15_3  lx15_4  lx15_5  lx15_6  lx15_7  lx15_8  lx15_9  lx15_10  lx15_11                                    } where (_TYPE_="PARMS") into Lx_hat[colname=Lx_name];
read all var {
corr_y21
corr_y31  corr_y32
corr_y41  corr_y42  corr_y43
corr_y51  corr_y52  corr_y53  corr_y54
corr_y61  corr_y62  corr_y63  corr_y64  corr_y65
corr_y71  corr_y72  corr_y73  corr_y74  corr_y75  corr_y76
corr_y81  corr_y82  corr_y83  corr_y84  corr_y85  corr_y86  corr_y87
corr_y91  corr_y92  corr_y93  corr_y94  corr_y95  corr_y96  corr_y97  corr_y98
corr_y10_1  corr_y10_2  corr_y10_3  corr_y10_4  corr_y10_5  corr_y10_6  corr_y10_7  corr_y10_8  corr_y10_9} where (_TYPE_="PARMS") into Psi_hat[colname=Psi_name];
read all var {
cly11  cly12  cly13  cly14  cly15  cly16  cly17  cly18  cly19  cly1_10
cly21  cly22  cly23  cly24  cly25  cly26  cly27  cly28  cly29  cly2_10
cly31  cly32  cly33  cly34  cly35  cly36  cly37  cly38  cly39  cly3_10
cly41  cly42  cly43  cly44  cly45  cly46  cly47  cly48  cly49  cly4_10
cly51  cly52  cly53  cly54  cly55  cly56  cly57  cly58  cly59  cly5_10
cly61  cly62  cly63  cly64  cly65  cly66  cly67  cly68  cly69  cly6_10
cly71  cly72  cly73  cly74  cly75  cly76  cly77  cly78  cly79  cly7_10
cly81  cly82  cly83  cly84  cly85  cly86  cly87  cly88  cly89  cly8_10
cly91  cly92  cly93  cly94  cly95  cly96  cly97  cly98  cly99  cly9_10
cly10_1  cly10_2  cly10_3  cly10_4  cly10_5  cly10_6  cly10_7  cly10_8  cly10_9  cly10_10} where (_TYPE_="PARMS") into Ly_hat[colname=Ly_name];

read all var ("sd1":"sd15") where (_TYPE_="STDERR") into Dx_se;
read all var ("sd16":"sd25") where (_TYPE_="STDERR") into Dy_se;
read all var {
  lx11    lx12    lx13    lx14    lx15    lx16    lx17    lx18    lx19   lx1_10   lx1_11   lx1_12   lx1_13   lx1_14   lx1_15
  lx21    lx22    lx23    lx24    lx25    lx26    lx27    lx28    lx29   lx2_10   lx2_11   lx2_12   lx2_13   lx2_14   lx2_15
  lx31    lx32    lx33    lx34    lx35    lx36    lx37    lx38    lx39   lx3_10   lx3_11   lx3_12   lx3_13   lx3_14   lx3_15
  lx41    lx42    lx43    lx44    lx45    lx46    lx47    lx48    lx49   lx4_10   lx4_11   lx4_12   lx4_13   lx4_14   lx4_15
  lx51    lx52    lx53    lx54    lx55    lx56    lx57    lx58    lx59   lx5_10   lx5_11   lx5_12   lx5_13   lx5_14   lx5_15
  lx61    lx62    lx63    lx64    lx65    lx66    lx67    lx68    lx69   lx6_10   lx6_11   lx6_12   lx6_13   lx6_14   lx6_15
  lx71    lx72    lx73    lx74    lx75    lx76    lx77    lx78    lx79   lx7_10   lx7_11   lx7_12   lx7_13   lx7_14   lx7_15
  lx81    lx82    lx83    lx84    lx85    lx86    lx87    lx88    lx89   lx8_10   lx8_11   lx8_12   lx8_13   lx8_14   lx8_15
  lx91    lx92    lx93    lx94    lx95    lx96    lx97    lx98    lx99   lx9_10   lx9_11   lx9_12   lx9_13   lx9_14   lx9_15
lx10_1  lx10_2  lx10_3  lx10_4  lx10_5  lx10_6  lx10_7  lx10_8  lx10_9  lx10_10  lx10_11  lx10_12  lx10_13  lx10_14  lx10_15
lx11_1  lx11_2  lx11_3  lx11_4  lx11_5  lx11_6  lx11_7  lx11_8  lx11_9  lx11_10  lx11_11  lx11_12  lx11_13  lx11_14  lx11_15
lx12_1  lx12_2  lx12_3  lx12_4  lx12_5  lx12_6  lx12_7  lx12_8  lx12_9  lx12_10  lx12_11  lx12_12  lx12_13  lx12_14
lx13_1  lx13_2  lx13_3  lx13_4  lx13_5  lx13_6  lx13_7  lx13_8  lx13_9  lx13_10  lx13_11  lx13_12  lx13_13
lx14_1  lx14_2  lx14_3  lx14_4  lx14_5  lx14_6  lx14_7  lx14_8  lx14_9  lx14_10  lx14_11  lx14_12
lx15_1  lx15_2  lx15_3  lx15_4  lx15_5  lx15_6  lx15_7  lx15_8  lx15_9  lx15_10  lx15_11                                    } where (_TYPE_="STDERR") into Lx_se;
read all var {
corr_y21
corr_y31  corr_y32
corr_y41  corr_y42  corr_y43
corr_y51  corr_y52  corr_y53  corr_y54
corr_y61  corr_y62  corr_y63  corr_y64  corr_y65
corr_y71  corr_y72  corr_y73  corr_y74  corr_y75  corr_y76
corr_y81  corr_y82  corr_y83  corr_y84  corr_y85  corr_y86  corr_y87
corr_y91  corr_y92  corr_y93  corr_y94  corr_y95  corr_y96  corr_y97  corr_y98
corr_y10_1  corr_y10_2  corr_y10_3  corr_y10_4  corr_y10_5  corr_y10_6  corr_y10_7  corr_y10_8  corr_y10_9} where (_TYPE_="STDERR") into Psi_se;
read all var {
cly11  cly12  cly13  cly14  cly15  cly16  cly17  cly18  cly19  cly1_10
cly21  cly22  cly23  cly24  cly25  cly26  cly27  cly28  cly29  cly2_10
cly31  cly32  cly33  cly34  cly35  cly36  cly37  cly38  cly39  cly3_10
cly41  cly42  cly43  cly44  cly45  cly46  cly47  cly48  cly49  cly4_10
cly51  cly52  cly53  cly54  cly55  cly56  cly57  cly58  cly59  cly5_10
cly61  cly62  cly63  cly64  cly65  cly66  cly67  cly68  cly69  cly6_10
cly71  cly72  cly73  cly74  cly75  cly76  cly77  cly78  cly79  cly7_10
cly81  cly82  cly83  cly84  cly85  cly86  cly87  cly88  cly89  cly8_10
cly91  cly92  cly93  cly94  cly95  cly96  cly97  cly98  cly99  cly9_10
cly10_1  cly10_2  cly10_3  cly10_4  cly10_5  cly10_6  cly10_7  cly10_8  cly10_9  cly10_10} where (_TYPE_="STDERR") into Ly_se;
close est;

p = 15;
q = 10;

Lx_hat11 = shape(Lx_hat[1,1:11*p],11,p);
Lx_hat12 = shape(Lx_hat[1,11*p+1:11*p+p-1],1,p-1) || 0.122275143;
Lx_hat13 = shape(Lx_hat[1,11*p+p-1+1:11*p+p-1+p-2],1,p-2) || -0.173360631 || -0.057612697;
Lx_hat14 = shape(Lx_hat[1,11*p+p-1+p-2+1:11*p+p-1+p-2+p-3],1,p-3) || -0.098943935 || 0.033576129 || 0.393775731;
Lx_hat15 = shape(Lx_hat[1,11*p+p-1+p-2+p-3+1:11*p+p-1+p-2+p-3+p-4],1,p-4) || 0.055541165 || -0.314694613 || 0.624462503 || -0.291369847;
Lx_hat = Lx_hat11 // Lx_hat12 // Lx_hat13 // Lx_hat14 // Lx_hat15;
Lx_se11 = shape(Lx_se[1,1:11*p],11,p);
Lx_se12 = shape(Lx_se[1,11*p+1:11*p+p-1],1,p-1) || 999999;
Lx_se13 = shape(Lx_se[1,11*p+p-1+1:11*p+p-1+p-2],1,p-2) || 999999 || 999999;
Lx_se14 = shape(Lx_se[1,11*p+p-1+p-2+1:11*p+p-1+p-2+p-3],1,p-3) || 999999 || 999999 || 999999;
Lx_se15 = shape(Lx_se[1,11*p+p-1+p-2+p-3+1:11*p+p-1+p-2+p-3+p-4],1,p-4) || 999999 || 999999 || 999999 || 999999;
Lx_se = Lx_se11 // Lx_se12 // Lx_se13 // Lx_se14 // Lx_se15;
Psi_temp = I(q);
Psi_temp[2,1] = Psi_hat[,1];
Psi_temp[3,1:2] = Psi_hat[,2:3];
Psi_temp[4,1:3] = Psi_hat[,4:6];
Psi_temp[5,1:4] = Psi_hat[,7:10];
Psi_temp[6,1:5] = Psi_hat[,11:15];
Psi_temp[7,1:6] = Psi_hat[,16:21];
Psi_temp[8,1:7] = Psi_hat[,22:28];
Psi_temp[9,1:8] = Psi_hat[,29:36];
Psi_temp[10,1:9] =Psi_hat[,37:45];
Psi_hat = Psi_temp + T(Psi_temp) - I(q);
Psi_temp_se = 999999*I(q);
Psi_temp_se[2,1] = Psi_se[,1];
Psi_temp_se[3,1:2] = Psi_se[,2:3];
Psi_temp_se[4,1:3] = Psi_se[,4:6];
Psi_temp_se[5,1:4] = Psi_se[,7:10];
Psi_temp_se[6,1:5] = Psi_se[,11:15];
Psi_temp_se[7,1:6] = Psi_se[,16:21];
Psi_temp_se[8,1:7] = Psi_se[,22:28];
Psi_temp_se[9,1:8] = Psi_se[,29:36];
Psi_temp_se[10,1:9] =Psi_se[,37:45];
Psi_se = Psi_temp_se + T(Psi_temp_se) - 999999*I(q);
print Psi_se[f=7.3];
Ly_hat = shape(Ly_hat,q,q);
Ly_se = shape(Ly_se,q,q);

ods rtf file="Original RA-L_&method..rtf" style=journal;
print Dx_hat[f=8.4],, Dx_se[f=8.4],, Dy_hat[f=8.4],, Dy_se[f=8.4];
print Lx_hat[f=8.4],, Lx_se[f=8.4];
print Psi_hat[f=8.4],, Psi_se[f=8.4];
print Ly_hat[f=8.4],, Ly_se[f=8.4];
ods rtf close;

quit;

