options pagesize=70 linesize=140;
ods _all_ close;
ods listing;

libname a "";


proc import datafile="vanDam2011.sav" out=vanDam2011 dbms=sav replace;
run;


data a.vanDam2011;
  set vanDam2011;
  keep ZI01_4nul ZI02_4nul ZI03_4nul ZI04_4nul ZI05_4nul ZI06_4nul ZI07_4nul ZI08_4nul ZI09_4nul ZI10_4nul
       CFCnul RF_prevnul RF_promnul VAL_altrnul VAL_biosnul VAL_egonul NEPnul
       ENV_idnul ENV_affnul ETHICnul HLTH_prvnul HLTH_cncnul SVO_dSocnul SVO_dIndnul SVO_dCmpmul;
run;


/* regular RA: 15 predictors, 10 outcomes */
proc iml;

use a.vanDam2011;
read all var {CFCnul RF_prevnul RF_promnul VAL_altrnul VAL_biosnul VAL_egonul NEPnul
              ENV_idnul ENV_affnul ETHICnul HLTH_prvnul HLTH_cncnul SVO_dSocnul SVO_dIndnul SVO_dCmpmul
              ZI01_4nul ZI02_4nul ZI03_4nul ZI04_4nul ZI05_4nul ZI06_4nul ZI07_4nul ZI08_4nul ZI09_4nul ZI10_4nul} into data [colname=varname];
close a.vanDam2011;

p = 15;
q = 10;

varname_X = varname[1,1:p];
varname_Y = varname[1,p+1:p+q];

samp_corr = corr(data);

/* X'X correlation matrix */
sigma_11 = samp_corr[1:p,1:p];

/* Y'X correlation matrix */
sigma_21 = samp_corr[p+1:p+q,1:p];
sigma_12 = T(sigma_21);

/* Y'Y correlation matrix */
sigma_22 = samp_corr[p+1:p+q,p+1:p+q];

/***********************************************************************/
/****************** create X-side redundancy variates ******************/
/***********************************************************************/
tri_prod = inv(sigma_11)*sigma_12*sigma_21;
call eigen(val,vec,tri_prod);
scale = sqrt(diag(T(vec)*sigma_11*vec));
weight = vec*inv(scale); /* X-side weight matrix */
/*print weight[f=12.9];*/

cov_comp = T(weight)*sigma_11*weight;
print cov_comp[f=7.3];

/* orthogonalize the last 5 columns */
call eigen(val,vec,cov_comp[q+1:p,q+1:p]);
trans = block(I(q),vec);
weight_trans = weight*trans;
scale_trans = sqrt(diag(T(weight_trans)*sigma_11*weight_trans));
weight_new = weight_trans*inv(scale_trans);

weight_new = weight_new*diag({1 -1 -1 1 1 1 1 1 -1 1 1 1 1 1 1});
cov_comp = T(weight_new)*sigma_11*weight_new;
print cov_comp[f=7.3];
print weight_new[f=12.9];

/* X-side loading matrix */
loading = inv(T(weight_new));
print loading[f=12.9];
/* verify constraints */
print (loading*T(loading));
/*print (sigma_11*weight_new)[f=12.9][l="Alternatively, loading = sigma_11*weight"];*/

crsloading = sigma_21*weight_new; /* cross-loading matrix between Y-side varaibles and X-side components */
print crsloading[f=12.9];
/* verify constraints */
print (T(crsloading[,1:q])*crsloading[,1:q]);

red = 1/q*vecdiag(T(crsloading[,1:q])*crsloading[,1:q]); /* Y-side redundancy given the X-side components */
red_cum = {
1 0 0 0 0 0 0 0 0 0,
1 1 0 0 0 0 0 0 0 0,
1 1 1 0 0 0 0 0 0 0,
1 1 1 1 0 0 0 0 0 0,
1 1 1 1 1 0 0 0 0 0,
1 1 1 1 1 1 0 0 0 0,
1 1 1 1 1 1 1 0 0 0,
1 1 1 1 1 1 1 1 0 0,
1 1 1 1 1 1 1 1 1 0,
1 1 1 1 1 1 1 1 1 1}*red;
print red[f=7.3] " " red_cum[f=7.3];

create loading from loading [rowname=varname_X];
append from loading [rowname=varname_X];
close loading;

create crsloading from crsloading [rowname=varname_Y];
append from crsloading [rowname=varname_Y];
close crsloading;

quit;


/* Set the number of columns to be rotated */
%let m = 2;

data name(drop=i);
  do i = 1 to &m.;
    if i = 1 then _NAME_ = "Factor1";
    if i = 2 then _NAME_ = "Factor2";
    _TYPE_ = "PATTERN";
    output;
  end;
run;

proc transpose data=loading out=loading_tr(drop=_NAME_); run;

data loading_tr2(type=factor);
  merge name loading_tr;
  if _NAME_ = " " then delete;
run;

ods output OrthTrans=trans OrthRotFactPat=loading_rot;
proc factor data=loading_tr2 n=&m. method=pattern rotate=varimax;
run;


/* compute the rotated RA-L estimates */
proc iml;

use a.vanDam2011;
read all var {CFCnul RF_prevnul RF_promnul VAL_altrnul VAL_biosnul VAL_egonul NEPnul
              ENV_idnul ENV_affnul ETHICnul HLTH_prvnul HLTH_cncnul SVO_dSocnul SVO_dIndnul SVO_dCmpmul
              ZI01_4nul ZI02_4nul ZI03_4nul ZI04_4nul ZI05_4nul ZI06_4nul ZI07_4nul ZI08_4nul ZI09_4nul ZI10_4nul} into data [colname=varname];
close a.vanDam2011;

p = 15;
q = 10;

samp_corr = corr(data);
sigma_11 = samp_corr[1:p,1:p];
sigma_21 = samp_corr[p+1:p+q,1:p];
sigma_12 = T(sigma_21);
sigma_22 = samp_corr[p+1:p+q,p+1:p+q];

use loading;
read all var _NUM_ into loading;
close loading;
use crsloading;
read all var _NUM_ into crsloading;
close crsloading;

use trans;
read all var _NUM_ into trans;
close trans;
use loading_rot;
read all var _NUM_ into loading_rot;
close loading_rot;

loading_rot_full = loading_rot || loading[,&m.+1:p];
/* verify constraints */
print (loading_rot_full*T(loading_rot_full));

crsloading_rot = crsloading[,1:&m.]*inv(T(trans));
crsloading_rot_full = crsloading_rot || crsloading[,&m.+1:q] || J(q,p-q,0);
/* verify constraints: the constraint on the first 2 columns is violated after rotation */
print (T(crsloading_rot_full[,1:q])*crsloading_rot_full[,1:q]);

crsloading_rot_full_sq = crsloading_rot_full##2;
crsloading_rot_full_sq_colsum = T(J(1,q,1)*crsloading_rot_full_sq[,1:q]);
red_rot = crsloading_rot_full_sq_colsum/q; /* redundancy indices after rotation */
print red_rot[f=7.3][l="redundancy indices after Varimax rotation"];

create loading_rot_full from loading_rot_full;
append from loading_rot_full;
close loading_rot_full;

create sigma_22 from sigma_22;
append from sigma_22;
close sigma_22;

create crsloading_rot_full from crsloading_rot_full;
append from crsloading_rot_full;
close crsloading_rot_full;

quit;



/************** Hessian matrix of ULS function and Pseudo values **************/
proc iml;

start stack_parm(parm,parmloc,parmdim,beta,lambda,std);
  parm=J(1,parmdim,999999);
  do i = 1 to nrow(parmloc);
    col1=parmloc[i,1]; col2=parmloc[i,2]; col3=parmloc[i,3]; col4=parmloc[i,4];
    if col1=1 then parm[col4] = beta[col2,col3];
    if col1=2 then parm[col4] = lambda[col2,col3];
    if col1=3 then parm[col4] = std[col2,col3];
  end;
finish stack_parm;


start unpack_matrix(beta,lambda,std,parmloc,parm,p,q);
beta = block(J(p,p,0),I(q));
lambda = I(p+q);
std = 0*I(p+q);
  do i = 1 to nrow(parmloc);
    col1=parmloc[i,1]; col2=parmloc[i,2]; col3=parmloc[i,3]; col4=parmloc[i,4];
    if col1=1 then beta[col2,col3] = parm[col4];
    if col1=2 then lambda[col2,col3] = parm[col4];
    if col1=3 then std[col2,col3] = parm[col4];
  end;
beta[12,15] = 0.122275143;
beta[13,14:15] = {-0.173360631 -0.057612697};
beta[14,13:15] = {-0.098943935  0.033576129  0.393775731};
beta[15,12:15] = {0.055541165 -0.314694613  0.624462503 -0.291369847};
lambda[1:p,p+1:p+q] = T(lambda[p+1:p+q,1:p]);
lambda[p+1:p+q,p+1:p+q] = lambda[p+1:p+q,p+1:p+q] + T(lambda[p+1:p+q,p+1:p+q]) - I(q);
finish unpack_matrix;
/*run unpack_matrix(beta,lambda,std,parmloc,parm,p,q);*/
/*print beta[f=7.3],, lambda[f=7.3];*/


/********* Define the FDD and FDDFDD modules that compute numeric derivatives. *********/
/* The two module have identical functionality and only differ in the name.
   The FDDFDD module will be called within the FDD model.
   If the FDD module is called within the FDD module, SAS will report the error message that
   "ERROR: Module FDD called again before exit from prior call." */
start fdd(grad,func,parm);
small = 1E-7;
grad = J(1,ncol(parm),0);
cmd0 = "v0 = " + func + "(parm);";
call execute(cmd0);
do i = 1 to ncol(parm);
  increm = J(1,ncol(parm),0);
  increm[i] = small;
  parm_i = parm + increm;
  cmd_i = "v_i = " + func + "(parm_i);";
  call execute(cmd_i);
  grad[i] = (v_i - v0)/small;
end;
finish fdd;

start fddfdd(grad,func,parm);
small = 1E-7;
grad = J(1,ncol(parm),0);
cmd0 = "v0 = " + func + "(parm);";
call execute(cmd0);
do i = 1 to ncol(parm);
  increm = J(1,ncol(parm),0);
  increm[i] = small;
  parm_i = parm + increm;
  cmd_i = "v_i = " + func + "(parm_i);";
  call execute(cmd_i);
  grad[i] = (v_i - v0)/small;
end;
finish fddfdd;
/********* End of defining the FDD and FDDFDD modules *********/

use a.vanDam2011;
read all var {CFCnul RF_prevnul RF_promnul VAL_altrnul VAL_biosnul VAL_egonul NEPnul
              ENV_idnul ENV_affnul ETHICnul HLTH_prvnul HLTH_cncnul SVO_dSocnul SVO_dIndnul SVO_dCmpmul
              ZI01_4nul ZI02_4nul ZI03_4nul ZI04_4nul ZI05_4nul ZI06_4nul ZI07_4nul ZI08_4nul ZI09_4nul ZI10_4nul} into data [colname=varname];
close a.vanDam2011;

p = 15;
q = 10;

n = nrow(data);
mean = mean(data);
samp_cov = cov(data);

std = diag(std(data));

use loading_rot_full;
read all var _NUM_ into loading_rot_full;
close loading_rot_full;
beta = block(loading_rot_full,I(q));
/*print beta[f=7.3];*/

use sigma_22;
read all var _NUM_ into sigma_22;
close sigma_22;
use crsloading_rot_full;
read all var _NUM_ into crsloading_rot_full;
close crsloading_rot_full;
lambda = block(I(p),sigma_22);
lambda[p+1:p+q,1:p] = crsloading_rot_full;
lambda[1:p,p+1:p+q] = T(lambda[p+1:p+q,1:p]);
/*print lambda[f=7.3];*/

/****** collect (p+q) elements in STD ******/
col23_std = J(1,2,999);
do row = 1 to p+q;
  col = row;
  col23_std = col23_std // (row || col);
end;
col23_std = col23_std[2:nrow(col23_std),];
nparm_std = nrow(col23_std);
col1_std = J(nparm_std,1,3);
parmloc_std = col1_std || col23_std;
/*print parmloc_std;*/
/****** collect p*p-d(d-1)/2 loadings in BETA ******/
col23_beta = J(1,2,999);
do row = 1 to 11;
  do col = 1 to p;
    col23_beta = col23_beta // (row || col);
  end;
end;
row = 12;
  do col = 1 to p-1;
    col23_beta = col23_beta // (row || col);
  end;
row = 13;
  do col = 1 to p-2;
    col23_beta = col23_beta // (row || col);
  end;
row = 14;
  do col = 1 to p-3;
    col23_beta = col23_beta // (row || col);
  end;
row = 15;
  do col = 1 to p-4;
    col23_beta = col23_beta // (row || col);
  end;col23_beta = col23_beta[2:nrow(col23_beta),];
nparm_beta = nrow(col23_beta);
col1_beta = J(nparm_beta,1,1);
parmloc_beta = col1_beta || col23_beta;
/*print parmloc_beta;*/
/****** collect q*q cross-loadings in LAMBDA ******/
col23_cl = J(1,2,999);
do row = p+1 to p+q;
  do col = 1 to q;
    col23_cl = col23_cl // (row || col);
  end;
end;
col23_cl = col23_cl[2:nrow(col23_cl),];
nparm_cl = nrow(col23_cl);
col1_cl = J(nparm_cl,1,2);
parmloc_cl = col1_cl || col23_cl;
/*print parmloc_cl;*/
/****** collect q*(q-1)/2 Y-side correlations in LAMBDA ******/
col23_corr = J(1,2,999);
do row = p+2 to p+q;
  do col = p+1 to row-1;
    col23_corr = col23_corr // (row || col);
  end;
end;
col23_corr = col23_corr[2:nrow(col23_corr),];
nparm_corr = nrow(col23_corr);
col1_corr = J(nparm_corr,1,2);
parmloc_corr = col1_corr || col23_corr;
/*print parmloc_corr;*/

parmdim = nparm_std + nparm_beta + nparm_cl + nparm_corr;
parmloc = (parmloc_std // parmloc_beta // parmloc_cl // parmloc_corr) || T(do(1,parmdim,1));
/*print parmloc;*/

run stack_parm(parm,parmloc,parmdim,beta,lambda,std);

start ULS_func(parm) global(beta,lambda,std,parmloc,p,q,  samp_cov);
run unpack_matrix(beta,lambda,std,parmloc,parm,p,q);
model_cov = std*beta*lambda*T(beta)*std;
ULS_function = 0.5*trace((samp_cov - model_cov)**2);
/*print ULS_function;*/
return(ULS_function);
finish ULS_func;

call nlpfdd(func,grad,hess,"ULS_func",parm);


/* numeric partial derivatives for diag(P)=I */
jacob_P = J(15,parmdim,0);
%Macro jacob_P;
%do i = 1 %to 15;
%put i=&i.;
start nlcon(parm) global(beta,lambda,std,parmloc,p,q,   constr);
  run unpack_matrix(beta,lambda,std,parmloc,parm,p,q);
  p_matrix = beta*lambda*T(beta);
  constr = J(p,1,1) - vecdiag(p_matrix[1:p,1:p]);
/*  print constr;*/
return(constr[&i.]);
finish nlcon;

run fdd(G&i.,"nlcon",parm);
jacob_P[&i.,] = G&i.;

%end;
%Mend jacob_P;
%jacob_P;


/* numeric partial derivatives for T(crsloading_rot_full)*crsloading_rot_full */
jacob_CL = J(44,parmdim,0);
%Macro jacob_CL;
%do i = 1 %to 44;
%put i=&i.;
start nlcon(parm) global(beta,lambda,std,parmloc,p,q,   constr);
  run unpack_matrix(beta,lambda,std,parmloc,parm,p,q);
  crsloading_rot_full = lambda[p+1:p+q,1:p];
  temp = T(crsloading_rot_full[,1:q])*crsloading_rot_full[,1:q];
/*  print temp;*/
  constr = T(temp[3,1:2] || temp[4,1:3] || temp[5,1:4] || temp[6,1:5] || temp[7,1:6] || temp[8,1:7] || temp[9,1:8] || temp[10,1:9]);
/*  print constr,, (nrow(constr));*/
return(constr[&i.]);
finish nlcon;

run fdd(G&i.,"nlcon",parm);
jacob_CL[&i.,] = G&i.;

%end;
%Mend jacob_CL;
%jacob_CL;


/********** constraints for Varimax with Kaiser's normalization **********/
/* normalize the rotated matrices */
loading_rot = loading_rot_full[,1:&m.];
communality = diag(loading_rot*T(loading_rot));
loading_norm_full = inv(sqrt(communality))*loading_rot || loading_rot_full[,&m.+1:p];
beta_norm = block(loading_norm_full,I(q));
print (beta_norm[1:p,1:&m.]);
run stack_parm(parm_norm,parmloc,parmdim,beta_norm,lambda,std);   /* Create a parameter vector that contains the normalized loadings. */
/*print (parm - parm_norm);*/
/* The non-zero elements in the above difference vector indicate the locations of normalized loadings in the parm_norm vector. */

/* define the simplicity function of normalized Varimax */
start simp_func(parm_norm) global(parmloc,p,q);
run unpack_matrix(beta_norm,lambda,std,parmloc,parm_norm,p,q);
matrix = beta_norm[1:p,1:&m.];
matrix_sq = matrix##2;
var_col = var(matrix_sq);
Varimax = sum(var_col);
return(Varimax);
finish simp_func;


/* Orthogonal rotation has m(m-1)/2 constraints. */
jacob_Rot = J(1,parmdim,0);
%Macro jacob_Rot;
%do i = 1 %to 1;
%put i=&i.;
/* define the constraints for normalized Varimax, that is, A'*dh/dA is a symmetric matrix, where A is the rotated matrix. */
start nlcon_Rot(parm_norm) global(parmloc,p,q,  RotConstraint);
run unpack_matrix(beta_norm,lambda,std,parmloc,parm_norm,p,q);
matrix = beta_norm[1:p,1:&m.];
/*print matrix;*/

run fddfdd(Grad,"simp_func",parm_norm);   /* Compute partial derivatives of simplicity function w.r.t. normalized loadings */
run unpack_matrix(beta_grad,lambda_grad,std_grad,parmloc,Grad,p,q);
matrix_grad = beta_grad[1:p,1:&m.];

orthogonal = T(matrix)*matrix_grad;
RotConstraint = orthogonal[2,1] - orthogonal[1,2];
/*print orthogonal,, RotConstraint;*/
return(RotConstraint[&i.]);
finish nlcon_Rot;

run fdd(G_Rot&i.,"nlcon_Rot",parm_norm); /* call FDD --> call nlcon_Rot --> call FDDFDD */
jacob_Rot[&i.,] = G_Rot&i.;

%end;
%Mend jacob_Rot;
%jacob_Rot;
print RotConstraint;


/********** Jacobian for diag(P)=I and the rotation constraints **********/
jacob = jacob_P // jacob_CL // jacob_Rot;


/**************** J matrix ****************/
J_matrix = hess // jacob;
/*print "sample size =" n,, "# of rows in J =" (nrow(J_matrix)),, "# of columns in J =" (ncol(J_matrix));*/


/************** Jacobian of vec(sigma) w.r.t. parameter estimates **************/
jacob_Sigma = J((p+q)*(p+q),parmdim,0);
%Macro jacob_Sigma;
%do i = 1 %to 625;
%put i=&i.;
start optfunc(parm) global(p,q,beta,lambda,std,parmloc,parmdim,sigma,sigma_col);
run unpack_matrix(beta,lambda,std,parmloc,parm,p,q);
sigma = std*beta*lambda*T(beta)*std;
sigma_col = shapecol(sigma,0,1);
return(sigma_col[&i.]);
finish optfunc;
run fdd(G&i.,"optfunc",parm);
jacob_Sigma[&i.,] = G&i.;
%end;
%Mend jacob_Sigma;
%jacob_Sigma;
/*print (nrow(jacob_Sigma)) (ncol(jacob_Sigma));*/


/************** Pseudo values **************/
pseudo = J(n,parmdim,999999);
ord = J(1, ncol(J_matrix), 0);
do i = 1 to n;
  c = T(data[i,] - mean);
  cc_vec = shapecol(c*T(c),0,1);
  k_i_neg = T(jacob_Sigma)*cc_vec // J(nrow(J_matrix)-ncol(J_matrix),1,0);
  call qr(q_decomp, r_decomp, piv, lindep, J_matrix, ord, k_i_neg);
  solution = inv(r_decomp)*q_decomp[1:ncol(J_matrix),1];
  pseudo[i,piv] = T(solution);
end;
pseudo_se = std(pseudo);
parm_se = pseudo_se/sqrt(n);
/*print parm_se;*/


run unpack_matrix(beta_se,lambda_se,std_se,parmloc,parm_se,p,q);

Lx_rotated = beta[1:p,1:&m.];
Ly_rotated = lambda[p+1:p+q,1:&m.];
Lx_rotated_se = beta_se[1:p,1:&m.];
Ly_rotated_se = lambda_se[p+1:p+q,1:&m.];
Lx_rotated_t = (abs(Lx_rotated) - .3)/Lx_rotated_se;
Ly_rotated_t = (abs(Ly_rotated) - .3)/Ly_rotated_se;
Lx_rotated_p = 1-cdf("NORMAL",Lx_rotated_t);
Ly_rotated_p = 1-cdf("NORMAL",Ly_rotated_t);

ods rtf file="Modified RA_L_IJ.rtf" style=journal;
print "Rotated redundancy loadings",, Lx_rotated[f=7.4] " " Lx_rotated_se[f=7.4],,
      "A small p-value means that the rotated loading is larger than 0.3", Lx_rotated_t[f=7.4] " " Lx_rotated_p[f=9.4],,
      "Rotated cross-loadings",, Ly_rotated[f=7.4] " " Ly_rotated_se[f=7.4],,
      "A small p-value means that the rotated cross-loading is larger than 0.3", Ly_rotated_t[f=7.4] " " Ly_rotated_p[f=9.4];
print (beta[1:p,1:p])[f=7.4][l="loading"],, (beta_se[1:p,1:p])[f=7.4],,
      (lambda[p+1:p+q,p+1:p+q])[f=7.4][l="corr_y"],, (lambda_se[p+1:p+q,p+1:p+q])[f=7.4],,
      (lambda[p+1:p+q,1:q])[f=7.4][l="crossloading"],, (lambda_se[p+1:p+q,1:q])[f=7.4],,
      (T(vecdiag(std)))[f=7.4][l="std"],, (T(vecdiag(std_se)))[f=7.4];
ods rtf close;

quit;
